
import { useEffect } from 'react';
import { Link } from 'react-router-dom';
import Navigation from '@/components/Navigation';
import Footer from '@/components/Footer';
import { Card, CardContent } from '@/components/ui/card';
import { Collapsible, CollapsibleContent, CollapsibleTrigger } from '@/components/ui/collapsible';
import { GraduationCap, Clock, ChevronDown } from 'lucide-react';
import NewsletterSignup from '@/components/NewsletterSignup';
import SEOHead from '@/components/SEOHead';

const Teachers = () => {
  const schema = {
    "@context": "https://schema.org",
    "@type": "Organization",
    "name": "The IEP Coach - Special Education Advocacy and Support",
    "description": "Professional advocacy services supporting families, students, and educators through expert IEP representation, legal education consulting, and special education resources.",
    "mainEntity": {
      "@type": "DefinedTermSet",
      "name": "Special Education Advocacy Keywords",
      "url": "https://www.theiepcoach.com",
      "hasDefinedTerm": [
        { "@type": "DefinedTerm", "name": "Professional Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Support" },
        { "@type": "DefinedTerm", "name": "Expert IEP Advocacy" },
        { "@type": "DefinedTerm", "name": "Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Education Services" },
        { "@type": "DefinedTerm", "name": "IEP Coach" },
        { "@type": "DefinedTerm", "name": "Special Education Advocacy" },
        { "@type": "DefinedTerm", "name": "Family Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Services" },
        { "@type": "DefinedTerm", "name": "Education Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Advocacy Support" },
        { "@type": "DefinedTerm", "name": "Educational Advocacy" },
        { "@type": "DefinedTerm", "name": "Professional Advocacy Consultant" },
        { "@type": "DefinedTerm", "name": "Legal Education Advocate Services" },
        { "@type": "DefinedTerm", "name": "Disability Education Support" },
        { "@type": "DefinedTerm", "name": "Expert IEP Consultant" },
        { "@type": "DefinedTerm", "name": "Best IEP Advocate Services" },
        { "@type": "DefinedTerm", "name": "TheIEPCoach" },
        { "@type": "DefinedTerm", "name": "Educational Legal Advocacy" }
      ]
    }
  };

  return (
    <div className="min-h-screen">
      <SEOHead
        title="IEP Resources for Teachers & Special Education Staff | The IEP Coach"
        description="Essential IEP resources for teachers, special education staff, and case managers. ARD meeting preparation, compliance tools, and practical guidance for special education professionals."
        keywords="ARD, Special Education, Resource, Functional Academics, Behavior Support, MDR, IHP, Individualized Health Plan, IDEA, Sped, IEP resources for teachers, special education teacher tools, ARD meeting preparation, IEP compliance, special education case management, IEP goals writing, special education professional development"
        canonical="https://www.theiepcoach.com/teachers"
        openGraph={{
          title: "IEP Resources for Teachers & Special Education Staff - The IEP Coach",
          description: "Essential IEP resources for teachers, special education staff, and case managers. ARD meeting preparation, compliance tools, and practical guidance for special education professionals.",
          image: "https://www.theiepcoach.com/lovable-uploads/0a09e87f-544f-4502-bfe9-30850c1f8cdb.png",
          url: "https://www.theiepcoach.com/teachers"
        }}
        schema={schema}
      />
      <Navigation />
      
      {/* Hero Section */}
      <section className="bg-gradient-to-br from-primary to-blue-800 text-white py-16">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <h1 className="text-4xl lg:text-5xl font-heading font-bold mb-6">
            <span className="text-orange-400">IEP Coach Resources for Teachers</span>
          </h1>
          <p className="text-xl text-blue-100 max-w-3xl mx-auto mb-8">
            Equipping teachers with real-world IEP tools, special education guidance, and no-fluff resources—so you can show up strong for the students who need you most.
          </p>
          <div className="flex justify-center">
            <NewsletterSignup />
          </div>
        </div>
      </section>

      {/* Main Content */}
      <section className="py-16">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8">
          
          {/* Coming Soon Card */}
          <Card className="mb-8 bg-gradient-to-r from-accent/5 to-orange-50">
            <CardContent className="p-8 text-center">
              <div className="flex justify-center mb-6">
                <div className="bg-accent/10 rounded-full p-4">
                  <Clock className="h-12 w-12 text-accent" />
                </div>
              </div>
              <h2 className="text-3xl font-heading font-bold text-primary mb-4">
                Real Resources for Real Teachers
              </h2>
              <p className="text-lg text-gray-700 mb-6 max-w-2xl mx-auto">
                Resources that will really help teachers.
              </p>
            </CardContent>
          </Card>

          {/* What Teachers Need to Know */}
          <Card className="mb-8">
            <CardContent className="p-8">
              <h3 className="text-2xl font-heading font-bold text-primary mb-6 text-center">
                What Teachers Need to Know
              </h3>
              <div className="text-gray-700 leading-relaxed space-y-4">
                <p>
                  As a teacher working with students who have IEPs, you have specific legal responsibilities and rights. Understanding these can help you provide better support for your students while protecting yourself professionally.
                </p>
              </div>
              
              <h4 className="text-xl font-heading font-bold text-primary mb-4 mt-8">
                What Teachers Need to Know About Special Education Law
              </h4>
              
              <div className="space-y-4">
                <Collapsible>
                  <CollapsibleTrigger className="flex items-center text-left font-semibold text-gray-700 hover:text-primary transition-colors text-lg">
                    <ChevronDown className="h-4 w-4 mr-2" />
                    What is Endrew F. and how does it affect me?
                  </CollapsibleTrigger>
                  <CollapsibleContent className="mt-2 pl-6">
                    <p className="text-sm text-gray-600 mb-3">
                      Understanding this landmark Supreme Court case and its impact on your daily work with students who have IEPs.
                    </p>
                    <a 
                      href="/endrew-f-for-teachers" 
                      className="inline-flex items-center px-4 py-2 bg-primary text-white text-sm rounded-md hover:bg-primary/90 transition-colors"
                    >
                      Learn More
                    </a>
                  </CollapsibleContent>
                </Collapsible>
                
                <Collapsible>
                  <CollapsibleTrigger className="flex items-center text-left font-semibold text-gray-700 hover:text-primary transition-colors text-lg">
                    <ChevronDown className="h-4 w-4 mr-2" />
                    Who Can Teach Special Education? Understanding the Rules
                  </CollapsibleTrigger>
                  <CollapsibleContent className="mt-2 pl-6">
                    <p className="text-sm text-gray-600 mb-3">
                      Clear breakdown of what the law says about qualifications under IDEA and who is allowed to teach or provide services in special education.
                    </p>
                    <Link 
                      to="/personnel-qualifications-under-idea" 
                      className="inline-flex items-center px-4 py-2 bg-primary text-white text-sm rounded-md hover:bg-primary/90 transition-colors"
                    >
                      Learn More
                    </Link>
                  </CollapsibleContent>
                </Collapsible>
              </div>
            </CardContent>
          </Card>

          {/* Teacher Support Info */}
          <Card className="mb-8">
            <CardContent className="p-8">
              <div className="mb-6">
                <div>
                   <h3 className="text-2xl font-heading font-bold text-primary mb-4 text-center">
                     Tools & Resources for Teachers
                   </h3>
                   <p className="text-gray-700 leading-relaxed mb-6 text-center">
                     This section is built for you—the teacher caught between compliance and compassion, trying to do right by kids in a system that does not always make it easy.
                   </p>
                  
                   <ul className="space-y-4 text-gray-700 ml-6">
                     <li className="flex items-start">
                       <div>
                         <Collapsible>
                           <CollapsibleTrigger className="flex items-center text-left font-semibold text-gray-700 hover:text-primary transition-colors text-xl mt-2">
                             <ChevronDown className="h-4 w-4 mr-2" />
                             What the IEP actually requires (and what it does not)
                           </CollapsibleTrigger>
                           <CollapsibleContent className="mt-2 pl-6">
                             <p className="text-sm text-gray-600 mb-3">
                               Cut through the jargon. Know what is expected, what is flexible, and how to protect yourself while helping your students.
                             </p>
                             <a 
                               href="/teachers-responsibilities" 
                               className="inline-flex items-center px-4 py-2 bg-primary text-white text-sm rounded-md hover:bg-primary/90 transition-colors"
                             >
                               View IEP Responsibilities for Teachers
                             </a>
                           </CollapsibleContent>
                         </Collapsible>
                       </div>
                     </li>
                       <li className="flex items-start">
                         <div>
                           <Collapsible>
                             <CollapsibleTrigger className="flex items-center text-left font-semibold text-gray-700 hover:text-primary transition-colors text-xl mt-2">
                               <ChevronDown className="h-4 w-4 mr-2" />
                               Documentation that defends your work
                             </CollapsibleTrigger>
                             <CollapsibleContent className="mt-2 pl-6">
                               <p className="text-sm text-gray-600 mb-3">
                                 Best practices that keep your paperwork solid, your intentions clear, and your backside covered.
                               </p>
                               <a 
                                 href="/teacher-documentation-best-practices" 
                                 className="inline-flex items-center px-4 py-2 bg-primary text-white text-sm rounded-md hover:bg-primary/90 transition-colors"
                               >
                                 Learn Best Practices
                               </a>
                             </CollapsibleContent>
                           </Collapsible>
                         </div>
                       </li>
                       <li className="flex items-start">
                         <div>
                           <Collapsible>
                             <CollapsibleTrigger className="flex items-center text-left font-semibold text-gray-700 hover:text-primary transition-colors text-xl mt-2">
                               <ChevronDown className="h-4 w-4 mr-2" />
                               Working with Paraprofessionals
                             </CollapsibleTrigger>
                             <CollapsibleContent className="mt-2 pl-6">
                               <p className="text-sm text-gray-600 mb-3">
                                 Paraprofessionals play a critical role in inclusive classrooms, supporting students with disabilities while working under the supervision of certified teachers. This guide helps educators, administrators, and families understand how to legally and effectively integrate paraprofessionals into instructional settings.
                               </p>
                               <a 
                                 href="/working-with-paraprofessionals" 
                                 className="inline-flex items-center px-4 py-2 bg-accent text-white text-sm rounded-md hover:bg-accent/90 transition-colors"
                               >
                                 View Complete Guide
                               </a>
                             </CollapsibleContent>
                           </Collapsible>
                         </div>
                       </li>
                     <li className="flex items-start">
                       <div>
                         <strong>Collaboration without confrontation</strong><br />
                         <span className="text-sm">Learn how to team up with families and advocates without feeling steamrolled or silenced.</span>
                       </div>
                     </li>
                     <li className="flex items-start">
                       <div>
                         <strong>Professional development that does not waste your time</strong><br />
                         <span className="text-sm">Short, sharp trainings that actually help you in the classroom tomorrow not just on a quiz at the end.</span>
                       </div>
                     </li>
                   </ul>
                </div>
              </div>
            </CardContent>
          </Card>

          {/* Contact Info */}
          <Card>
            <CardContent className="p-8 text-center">
              <h3 className="text-xl font-heading font-bold text-primary mb-4">
                Have Questions or Suggestions?
              </h3>
              <p className="text-gray-700 mb-6">
                If you're a teacher with specific questions or would like to suggest topics for this section, please don't hesitate to reach out.
              </p>
              <a 
                href="/teachers-contact" 
                className="inline-flex items-center px-6 py-3 bg-accent text-white font-semibold rounded-lg hover:bg-accent/90 transition-colors"
              >
                Contact Us
              </a>
            </CardContent>
          </Card>

        </div>
      </section>

      <Footer />
    </div>
  );
};

export default Teachers;
